@@ -1,48 +1,36 @@
-from functools import partial
-
-try:
-    from functools import partialmethod
-except ImportError:
-    from django.utils.functional import curry as partialmethod
+from functools import partial, partialmethod
 
 from django import forms
-from django.forms.formsets import all_valid
-from django.urls import reverse
+from django.apps import apps
+from django.conf import settings
+from django.contrib.admin import helpers, widgets
 from django.contrib.admin.exceptions import DisallowedModelAdminToField
-from django.contrib.admin import widgets, helpers
-from django.contrib.admin.utils import (
-    unquote, flatten_fieldsets, get_deleted_objects,
-)
-from django.contrib.admin.options import (
-    TO_FIELD_VAR, IS_POPUP_VAR,
-    get_ul_class, csrf_protect_m,
-)
-from django.utils.html import escape
+from django.contrib.admin.options import IS_POPUP_VAR, TO_FIELD_VAR, csrf_protect_m, get_ul_class
+from django.contrib.admin.utils import flatten_fieldsets, get_deleted_objects, unquote
 from django.core.exceptions import PermissionDenied
-try:
-    from django.db.models.related import RelatedObject
-except ImportError:
-    from django.db.models.fields.related import ForeignObjectRel as RelatedObject # noqa
+from django.forms.formsets import all_valid
+from django.forms.models import modelform_defines_fields
+from django.forms.utils import pretty_name
 from django.http import Http404
 from django.template.response import TemplateResponse
+from django.urls import reverse
+from django.utils.encoding import force_str
+from django.utils.html import escape
 from django.utils.text import capfirst
-from django.utils.translation import ugettext as _
-from django.forms.utils import pretty_name
-from django.forms.models import modelform_defines_fields
-from django.conf import settings
-from django.apps import apps
-
-from django_mongoengine.utils import force_text
-from django_mongoengine.fields import (ListField, EmbeddedDocumentField,
-                                       ReferenceField, StringField)
+from django.utils.translation import gettext as _
 
+from django_mongoengine.fields import EmbeddedDocumentField, ListField, ReferenceField, StringField
+from django_mongoengine.forms.documents import (
+    BaseInlineDocumentFormSet,
+    DocumentForm,
+    documentform_factory,
+    documentformset_factory,
+    inlineformset_factory,
+)
 from django_mongoengine.mongo_admin.util import RelationWrapper
 from django_mongoengine.paginator import Paginator
-from django_mongoengine.utils.wrappers import copy_class
 from django_mongoengine.utils.monkey import get_patched_django_module
-from django_mongoengine.forms.documents import (
-    DocumentForm, documentform_factory, documentformset_factory,
-    inlineformset_factory, BaseInlineDocumentFormSet)
+from django_mongoengine.utils.wrappers import copy_class
 
 
 def get_content_type_for_model(obj):
@@ -57,6 +45,7 @@ djmod = get_patched_django_module(
 
 class BaseDocumentAdmin(djmod.ModelAdmin):
     """Functionality common to both ModelAdmin and InlineAdmin."""
+
     form = DocumentForm
     paginator = Paginator
 
@@ -89,8 +78,11 @@ class BaseDocumentAdmin(djmod.ModelAdmin):
                     related_modeladmin and related_modeladmin.has_add_permission(request)
                 )
                 form_field.widget = widgets.RelatedFieldWidgetWrapper(
-                    form_field.widget, RelationWrapper(db_field.document_type), self.admin_site,
-                    can_add_related=can_add_related)
+                    form_field.widget,
+                    RelationWrapper(db_field.document_type),
+                    self.admin_site,
+                    can_add_related=can_add_related,
+                )
                 return form_field
 
         if isinstance(db_field, StringField):
@@ -118,13 +110,14 @@ class BaseDocumentAdmin(djmod.ModelAdmin):
         if db_field.name in self.radio_fields:
             # Avoid stomping on custom widget/choices arguments.
             if 'widget' not in kwargs:
-                kwargs['widget'] = widgets.AdminRadioSelect(attrs={
-                    'class': get_ul_class(self.radio_fields[db_field.name]),
-                })
+                kwargs['widget'] = widgets.AdminRadioSelect(
+                    attrs={
+                        'class': get_ul_class(self.radio_fields[db_field.name]),
+                    }
+                )
             if 'choices' not in kwargs:
                 kwargs['choices'] = db_field.get_choices(
-                    include_blank=db_field.blank,
-                    blank_choice=[('', _('None'))]
+                    include_blank=db_field.blank, blank_choice=[('', _('None'))]
                 )
         return db_field.formfield(**kwargs)
 
@@ -138,7 +131,9 @@ class BaseDocumentAdmin(djmod.ModelAdmin):
             kwargs['widget'] = widgets.ManyToManyRawIdWidget(db_field.rel, using=db)
             kwargs['help_text'] = ''
         elif db_field.name in (list(self.filter_vertical) + list(self.filter_horizontal)):
-            kwargs['widget'] = widgets.FilteredSelectMultiple(pretty_name(db_field.name), (db_field.name in self.filter_vertical))
+            kwargs['widget'] = widgets.FilteredSelectMultiple(
+                pretty_name(db_field.name), (db_field.name in self.filter_vertical)
+            )
 
         return db_field.formfield(**kwargs)
 
@@ -150,10 +145,7 @@ class BaseDocumentAdmin(djmod.ModelAdmin):
             return self.view_on_site(obj)
         elif self.view_on_site and hasattr(obj, 'get_absolute_url'):
             # use the ContentType lookup if view_on_site is True
-            return reverse('admin:view_on_site', kwargs={
-                'content_type_id': 0,
-                'object_id': obj.pk
-            })
+            return reverse('admin:view_on_site', kwargs={'content_type_id': 0, 'object_id': obj.pk})
 
 
 @copy_class(djmod.ModelAdmin)
@@ -166,14 +158,19 @@ class DocumentAdmin(BaseDocumentAdmin):
         self.opts = model._meta
         self.admin_site = admin_site
         super(DocumentAdmin, self).__init__(model, admin_site)
-        self.log = not settings.DATABASES.get('default', {}).get(
-            'ENGINE', 'django.db.backends.dummy'
-        ).endswith('dummy')
+        self.log = (
+            not settings.DATABASES.get('default', {})
+            .get('ENGINE', 'django.db.backends.dummy')
+            .endswith('dummy')
+        )
 
-# XXX: add inline init somewhere
+    # XXX: add inline init somewhere
     def _get_inline_instances(self):
         for f in self.model._fields.values():
-            if not (isinstance(f, ListField) and isinstance(getattr(f, 'field', None), EmbeddedDocumentField)) and not isinstance(f, EmbeddedDocumentField):
+            if not (
+                isinstance(f, ListField)
+                and isinstance(getattr(f, 'field', None), EmbeddedDocumentField)
+            ) and not isinstance(f, EmbeddedDocumentField):
                 continue
             # Should only reach here if there is an embedded document...
             if f.name in self.exclude:
@@ -230,8 +227,11 @@ class DocumentAdmin(BaseDocumentAdmin):
         }
         defaults.update(kwargs)
         return documentformset_factory(
-            self.model, self.get_changelist_form(request), extra=0,
-            fields=self.list_editable, **defaults
+            self.model,
+            self.get_changelist_form(request),
+            extra=0,
+            fields=self.list_editable,
+            **defaults
         )
 
     def get_changelist(self, request, **kwargs):
@@ -239,6 +239,7 @@ class DocumentAdmin(BaseDocumentAdmin):
         Returns the ChangeList class for use on the changelist page.
         """
         from django_mongoengine.mongo_admin.views import DocumentChangeList
+
         return DocumentChangeList
 
     def log_addition(self, request, object, message):
@@ -300,10 +301,14 @@ class DocumentAdmin(BaseDocumentAdmin):
                 raise PermissionDenied
 
             if obj is None:
-                raise Http404(_('%(name)s object with primary key %(key)r does not exist.') % {
-                    'name': force_text(opts.verbose_name), 'key': escape(object_id)})
+                raise Http404(
+                    _('%(name)s object with primary key %(key)r does not exist.')
+                    % {'name': force_str(opts.verbose_name), 'key': escape(object_id)}
+                )
 
         ModelForm = self.get_form(request, obj)
+        form_validated = False
+
         if request.method == 'POST':
             form = ModelForm(request.POST, request.FILES, instance=obj)
             if form.is_valid():
@@ -329,7 +334,9 @@ class DocumentAdmin(BaseDocumentAdmin):
             if add:
                 initial = self.get_changeform_initial_data(request)
                 form = ModelForm(initial=initial)
-                formsets, inline_instances = self._create_formsets(request, form.instance, change=False)
+                formsets, inline_instances = self._create_formsets(
+                    request, form.instance, change=False
+                )
             else:
                 form = ModelForm(instance=obj)
                 formsets, inline_instances = self._create_formsets(request, obj, change=True)
@@ -339,7 +346,8 @@ class DocumentAdmin(BaseDocumentAdmin):
             list(self.get_fieldsets(request, obj)),
             self.get_prepopulated_fields(request, obj),
             self.get_readonly_fields(request, obj),
-            model_admin=self)
+            model_admin=self,
+        )
         media = self.media + adminForm.media
 
         inline_formsets = self.get_inline_formsets(request, formsets, inline_instances, obj)
@@ -348,12 +356,11 @@ class DocumentAdmin(BaseDocumentAdmin):
 
         context = dict(
             self.admin_site.each_context(request),
-            title=(_('Add %s') if add else _('Change %s')) % force_text(opts.verbose_name),
+            title=(_('Add %s') if add else _('Change %s')) % force_str(opts.verbose_name),
             adminform=adminForm,
             object_id=object_id,
             original=obj,
-            is_popup=(IS_POPUP_VAR in request.POST or
-                      IS_POPUP_VAR in request.GET),
+            is_popup=(IS_POPUP_VAR in request.POST or IS_POPUP_VAR in request.GET),
             to_field=to_field,
             media=media,
             inline_admin_formsets=inline_formsets,
@@ -371,7 +378,9 @@ class DocumentAdmin(BaseDocumentAdmin):
 
         context.update(extra_context or {})
 
-        return self.render_change_form(request, context, add=add, change=not add, obj=obj, form_url=form_url)
+        return self.render_change_form(
+            request, context, add=add, change=not add, obj=obj, form_url=form_url
+        )
 
     @csrf_protect_m
     def delete_view(self, request, object_id, extra_context=None):
@@ -390,19 +399,20 @@ class DocumentAdmin(BaseDocumentAdmin):
 
         if obj is None:
             raise Http404(
-                _('%(name)s object with primary key %(key)r does not exist.') %
-                {'name': force_text(opts.verbose_name), 'key': escape(object_id)}
+                _('%(name)s object with primary key %(key)r does not exist.')
+                % {'name': force_str(opts.verbose_name), 'key': escape(object_id)}
             )
 
         # Populate deleted_objects, a data structure of all related objects that
         # will also be deleted.
         (deleted_objects, model_count, perms_needed, protected) = get_deleted_objects(
-            [obj], request, self.admin_site)
+            [obj], request, self.admin_site
+        )
 
         if request.POST:  # The user has already confirmed the deletion.
             if perms_needed:
                 raise PermissionDenied
-            obj_display = force_text(obj)
+            obj_display = force_str(obj)
             attr = str(to_field) if to_field else opts.pk.attname
             obj_id = obj.serializable_value(attr)
             self.log_deletion(request, obj, obj_display)
@@ -410,7 +420,7 @@ class DocumentAdmin(BaseDocumentAdmin):
 
             return self.response_delete(request, obj_display, obj_id)
 
-        object_name = force_text(opts.verbose_name)
+        object_name = force_str(opts.verbose_name)
 
         if perms_needed or protected:
             title = _("Cannot delete %(name)s") % {"name": object_name}
@@ -429,8 +439,7 @@ class DocumentAdmin(BaseDocumentAdmin):
             opts=opts,
             app_label=app_label,
             preserved_filters=self.get_preserved_filters(request),
-            is_popup=(IS_POPUP_VAR in request.POST or
-                      IS_POPUP_VAR in request.GET),
+            is_popup=(IS_POPUP_VAR in request.POST or IS_POPUP_VAR in request.GET),
             to_field=to_field,
         )
         context.update(extra_context or {})
@@ -440,14 +449,18 @@ class DocumentAdmin(BaseDocumentAdmin):
     def history_view(self, request, object_id, extra_context=None):
         "The 'history' admin view for this model."
         from django.contrib.admin.models import LogEntry
+
         # First check if the user can see this history.
         model = self.model
         obj = self.get_object(request, unquote(object_id))
         if obj is None:
-            raise Http404(_('%(name)s object with primary key %(key)r does not exist.') % {
-                'name': force_text(model._meta.verbose_name),
-                'key': escape(object_id),
-            })
+            raise Http404(
+                _('%(name)s object with primary key %(key)r does not exist.')
+                % {
+                    'name': force_str(model._meta.verbose_name),
+                    'key': escape(object_id),
+                }
+            )
 
         if not self.has_change_permission(request, obj):
             raise PermissionDenied
@@ -455,16 +468,19 @@ class DocumentAdmin(BaseDocumentAdmin):
         # Then get the history for this object.
         opts = model._meta
         app_label = opts.app_label
-        action_list = LogEntry.objects.filter(
-            object_id=unquote(object_id),
-            content_type=get_content_type_for_model(model)
-        ).select_related().order_by('action_time')
+        action_list = (
+            LogEntry.objects.filter(
+                object_id=unquote(object_id), content_type=get_content_type_for_model(model)
+            )
+            .select_related()
+            .order_by('action_time')
+        )
 
         context = dict(
             self.admin_site.each_context(request),
-            title=_('Change history: %s') % force_text(obj),
+            title=_('Change history: %s') % force_str(obj),
             action_list=action_list,
-            module_name=capfirst(force_text(opts.verbose_name_plural)),
+            module_name=capfirst(force_str(opts.verbose_name_plural)),
             object=obj,
             opts=opts,
             preserved_filters=self.get_preserved_filters(request),
@@ -473,11 +489,16 @@ class DocumentAdmin(BaseDocumentAdmin):
 
         request.current_app = self.admin_site.name
 
-        return TemplateResponse(request, self.object_history_template or [
-            "admin/%s/%s/object_history.html" % (app_label, opts.model_name),
-            "admin/%s/object_history.html" % app_label,
-            "admin/object_history.html"
-        ], context)
+        return TemplateResponse(
+            request,
+            self.object_history_template
+            or [
+                "admin/%s/%s/object_history.html" % (app_label, opts.model_name),
+                "admin/%s/object_history.html" % app_label,
+                "admin/object_history.html",
+            ],
+            context,
+        )
 
 
 class InlineDocumentAdmin(BaseDocumentAdmin):
@@ -487,6 +508,7 @@ class InlineDocumentAdmin(BaseDocumentAdmin):
     ``model`` to its parent. This is required if ``model`` has more than one
     ``ForeignKey`` to its parent.
     """
+
     document = None
     fk_name = None
     formset = BaseInlineDocumentFormSet
@@ -561,10 +583,16 @@ class EmbeddedDocumentAdmin(InlineDocumentAdmin):
         self.rel_name = field.name
 
         if self.verbose_name is None:
-            self.verbose_name = "Field: %s (Document: %s)" % (capfirst(field.name), self.model._meta.verbose_name)
+            self.verbose_name = "Field: %s (Document: %s)" % (
+                capfirst(field.name),
+                self.model._meta.verbose_name,
+            )
 
         if self.verbose_name_plural is None:
-            self.verbose_name_plural = "Field: %s (Document:  %s)" % (capfirst(field.name), self.model._meta.verbose_name_plural)
+            self.verbose_name_plural = "Field: %s (Document:  %s)" % (
+                capfirst(field.name),
+                self.model._meta.verbose_name_plural,
+            )
 
         super(EmbeddedDocumentAdmin, self).__init__(parent_document, admin_site)
 
